{% extends 'qa/base.html' %}
{% load django_markdown %}

{% block content %}

  {% if message %}
  <strong>Enter a valid Question!</strong>
  {% endif %}

  <form method="post" action="{% block action_url %}{% url 'qa_create_question' %}{% endblock action_url %}">
    {{ form.as_p }}
    {% csrf_token %}
    <input class="btn pull-right btn-success" type="submit" value="Submit Question" />
  </form>

</div>

{% endblock content %}

{% block extra_js %}
  {% markdown_editor "#id_description" %}
  {% markdown_media %}
{% endblock extra_js %}
