{% extends 'qa/base.html' %}
{% load django_markdown %}

{% block content %}
<h2 class="pull-right">Points: {{ user.points }}</h1>
<ul>
  <li><b>Website :</b> {{ user.website }} </li>
   <li><b>e-mail :</b> {{ user.user.email }} </li>
   <li><b>Date Joined :</b> {{ user.user.date_joined }} </li>
   <li><b>Last Login :</b> {{ user.user.last_login }} </li>
   <li><b>is Active :</b> {{ user.user.is_active }} </li>
<ul>

</div>
{% endblock content %}
