# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-07-19 12:29
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qa', '0007_answer_total_points'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='userqaprofile',
            name='picture',
        ),
        migrations.AlterField(
            model_name='answer',
            name='updated',
            field=models.DateTimeField(auto_now=True, verbose_name='date updated'),
        ),
    ]
